"""Generate a strong password which includes alphabets, numbers, special characters"""

__version__ = '1.3.4'

from .__main__ import get_argument, generate_password, main
from .genpasswd import PasswordGenerator
